==> haskell-yesod-1.6.2.1-449-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod
version:              1.6.2.1
visibility:           public
id:                   yesod-1.6.2.1-2a4TBVtomshJ2OI7T9r0Bp
key:                  yesod-1.6.2.1-2a4TBVtomshJ2OI7T9r0Bp
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>

category:             Web, Yesod
abi:                  50a9b6e55ae107e21d6cfdbbac01aa21
exposed:              True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2
    Yesod.Default.Handlers Yesod.Default.Main Yesod.Default.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-1.6.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-1.6.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-1.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod
hs-libraries:         HSyesod-1.6.2.1-2a4TBVtomshJ2OI7T9r0Bp
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc directory-1.3.8.5
    fast-logger-3.2.4-AXHM12y5MtZKIIwsnmTfyz
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    monad-logger-0.3.42-A8mPheDcfh1Ekf5r4bHp7w
    shakespeare-2.1.7-EQa3S9NEyAK816psNg58s0
    streaming-commons-0.2.3.1-J8SxFARI4BPDYt3Np6OVv5
    template-haskell-2.20.0.0 text-2.0.2 unix-2.8.4.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63
    wai-extra-3.1.18-1ANzYYqVephHj2C1lo6Zwk
    wai-logger-2.5.0-VBPNbjn5lcBUCsraseoRs
    warp-3.4.0-EMEx6bSExsO4TCzNcPaO2H
    yaml-0.11.11.2-HJgRwey6BMIIq0hOFQKRBa
    yesod-core-1.6.27.1-KtBa6Xls8994lQw12Q4B1F
    yesod-form-1.7.9-GUMlEsGVy6YAaQxgbLNWHz
    yesod-persistent-1.6.0.8-1PT3vTEjdj623nY4CmQUQK

haddock-interfaces:   /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html:         /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-1.6.2.1-451-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod
version:              1.6.2.1
visibility:           public
id:                   yesod-1.6.2.1-EHYiX6Nr14y39EVzLgET13
key:                  yesod-1.6.2.1-EHYiX6Nr14y39EVzLgET13
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>

category:             Web, Yesod
abi:                  45b1d6f5d554b2383b20b5ac4643932b
exposed:              True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2
    Yesod.Default.Handlers Yesod.Default.Main Yesod.Default.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-1.6.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-1.6.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-1.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod
hs-libraries:         HSyesod-1.6.2.1-EHYiX6Nr14y39EVzLgET13
depends:
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc directory-1.3.8.5
    fast-logger-3.2.4-Jiy7JoGUrfbVNzVDnbkpD
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    monad-logger-0.3.42-JqeTk6zPcDZE7ttxNu3qt7
    shakespeare-2.1.7-2tYm0ZnKNHbCMeQLiFCieX
    streaming-commons-0.2.3.1-p6JZxPGlgm2ju1b9E77qr
    template-haskell-2.20.0.0 text-2.0.2 unix-2.8.4.0
    unordered-containers-0.2.20.1-1hrud2F05KV7Rz7RsKTZ5O
    wai-3.2.4-BLc210LwMQhDvJHRqgIjev
    wai-extra-3.1.18-2NqKPuFl5Jd2v0if4D3Rrq
    wai-logger-2.5.0-7XRbr5ukpDX4gn1KareYel
    warp-3.4.0-Js0YTJVu1i5Lh7vUHNAyGE
    yaml-0.11.11.2-7sI7sa5XZN9728orpxXF0B
    yesod-core-1.6.27.1-4gpTrKJARZw1tOAQMfFW4B
    yesod-form-1.7.9-4CfkicQN4Gh1BZtbFMO3Cs
    yesod-persistent-1.6.0.8-I40uFRLoDqjJLxX37rzhLS

haddock-interfaces:   /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html:         /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
